# Imported from ../qtrade: nanobook v0.9 planning/spec context

Source snapshot date: 2026-02-10

Files copied here:

- `plan_nanobook_v0.9.md`
  - source: `../qtrade/nanobook/plan_nanobook_v0.9.md`
- `SPEC_nanobook_integration_v0.9.md`
  - source: `../qtrade/nanobook/SPEC_nanobook_integration_v0.9.md`
- `plan_qtrade_v3.md`
  - source: `../qtrade/plan_qtrade_v3.md`
- `plan_qtrade_v0.4.md`
  - source: `../qtrade/plan_qtrade_v0.4.md`
- `qtrade_nanobook_integration_vision.md`
  - source: `../qtrade/nanobook/qtrade_nanobook_integration_vision.md`

Selection rule:
- Included files that explicitly contain nanobook v0.9 plan/spec material or define the qtrade↔nanobook integration plan that references v0.9 rollout.
